"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getTextSync = exports.getText = exports.setTextSync = exports.setText = void 0;
const core_1 = require("@nativescript/core");
const writeToClipboard = (content) => {
    const clipboard = core_1.Utils.ad.getApplicationContext().getSystemService(android.content.Context.CLIPBOARD_SERVICE);
    const clip = android.content.ClipData.newPlainText("App clipboard data", content);
    clipboard.setPrimaryClip(clip);
};
const readFromClipboard = (clipboard) => {
    const item = clipboard.getPrimaryClip().getItemAt(0);
    let content = item.getText().toString();
    return content || "";
};
function setText(content) {
    return new Promise((resolve, reject) => {
        try {
            writeToClipboard(content);
            resolve();
        }
        catch (ex) {
            console.log("Error in clipboard.setText: " + ex);
            reject(ex);
        }
    });
}
exports.setText = setText;
function setTextSync(content) {
    try {
        writeToClipboard(content);
    }
    catch (ex) {
        console.log("Error in clipboard.setTextSync: " + ex);
    }
}
exports.setTextSync = setTextSync;
function getText() {
    return new Promise((resolve, reject) => {
        try {
            const clipboard = core_1.Utils.ad.getApplicationContext().getSystemService(android.content.Context.CLIPBOARD_SERVICE);
            if (!clipboard.getPrimaryClipDescription().hasMimeType(android.content.ClipDescription.MIMETYPE_TEXT_PLAIN) &&
                !clipboard.getPrimaryClipDescription().hasMimeType(android.content.ClipDescription.MIMETYPE_TEXT_HTML)) {
                reject("No compatible clipboard content found");
            }
            else {
                resolve(readFromClipboard(clipboard));
            }
        }
        catch (ex) {
            console.log("Error in clipboard.getText: " + ex);
            reject(ex);
        }
    });
}
exports.getText = getText;
function getTextSync() {
    try {
        const clipboard = core_1.Utils.ad.getApplicationContext().getSystemService(android.content.Context.CLIPBOARD_SERVICE);
        if (!clipboard.getPrimaryClipDescription().hasMimeType(android.content.ClipDescription.MIMETYPE_TEXT_PLAIN) &&
            !clipboard.getPrimaryClipDescription().hasMimeType(android.content.ClipDescription.MIMETYPE_TEXT_HTML)) {
            console.log("No compatible clipboard content found");
            return "";
        }
        else {
            return readFromClipboard(clipboard);
        }
    }
    catch (ex) {
        console.log("Error in clipboard.getText: " + ex);
        return "";
    }
}
exports.getTextSync = getTextSync;
//# sourceMappingURL=clipboard.android.js.map